From 01acf3798c41c632c733f9972ed245b0ff000a6a Mon Sep 17 00:00:00 2001
From: Cameron Nemo <cnemo@tutanota.com>
Date: Tue, 18 Jun 2019 19:37:27 -0700
Subject: [PATCH] build-style/go: use XBPS_MAKEJOBS to control parallelism

---
 Manual.md                | 7 ++++++-
 common/build-style/go.sh | 2 +-
 2 files changed, 7 insertions(+), 2 deletions(-)

diff --git a/Manual.md b/Manual.md
index ec5206bba58..7f6f23de59e 100644
--- a/Manual.md
+++ b/Manual.md
@@ -1460,7 +1460,7 @@ Go packages should be built with the `go` build style, if possible.
 The `go` build style takes care of downloading Go dependencies and
 setting up cross compilation.
 
-The following variables influence how Go packages are built:
+The following template variables influence how Go packages are built:
 
 - `go_import_path`: The import path of the package included in the
   distfile, as it would be used with `go get`. For example, GitHub's
@@ -1479,6 +1479,11 @@ The following variables influence how Go packages are built:
   accepted by `go build -mod MODE`.  Defaults to `vendor` if there's
   a vendor directory, otherwise `default`.
 
+The following environment variables influence how Go packages are built:
+
+- `XBPS_MAKEJOBS`: Value passed to the `-p` flag of `go install`, to
+  control the parallelism of the Go compiler.
+
 Occasionally it is necessary to perform operations from within the Go
 source tree.  This is usually needed by programs using go-bindata or
 otherwise preping some assets.  If possible do this in pre_build().
diff --git a/common/build-style/go.sh b/common/build-style/go.sh
index 98f95bea2e5..5242a446a15 100644
--- a/common/build-style/go.sh
+++ b/common/build-style/go.sh
@@ -33,7 +33,7 @@ do_build() {
 			# default behavior.
 			go_mod_mode=
 		fi
-		go install -mod="${go_mod_mode}" -x -tags "${go_build_tags}" -ldflags "${go_ldflags}" ${go_package}
+		go install -p "$XBPS_MAKEJOBS" -mod="${go_mod_mode}" -x -tags "${go_build_tags}" -ldflags "${go_ldflags}" ${go_package}
 	else
 		# Otherwise, build using GOPATH
 		go get -x -tags "${go_build_tags}" -ldflags "${go_ldflags}" ${go_package}
